@@ -31,11 +31,11 @@ fi
 # copy nvidia obsoleted drivers data
 cp /usr/share/ubuntu-drivers-common/obsolete ubuntu-drivers-obsolete.pkgs
 
-# create the tarball, copy links in place
+# create the tarball, copy links in place 
 tar -c -h -v --exclude DistUpgrade --exclude=$DIST.tar --exclude=$0 -X build-exclude.txt -f $DIST.tar  ./*
 
-# add *.cfg and *.ui to the tarball, copy links (demotions) in place
-tar --append -h -v -f $DIST.tar --transform 's|.*/|./|' ../data/*.cfg* ../data/gtkbuilder/*.ui ../data/*.gpg
+# add *.cfg and *.ui to the tarball
+tar --append -v -f $DIST.tar --transform 's|.*/|./|' ../data/*.cfg* ../data/gtkbuilder/*.ui
 
 # add "DistUpgrade"  symlink as symlink
 tar --append -v -f $DIST.tar ./DistUpgrade
